@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 9976 2017-05-16 06:31:28Z Lavender $
+# $Id: build_templates.py 9979 2017-05-20 16:33:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
-# $Revision: 9976 $
+# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
+# $Revision: 9979 $
 
 import os
 import sys
@@ -65,6 +65,33 @@ class Command(BaseCommand):
                     "build_boilerplate error code: %d, from template: %s" % 
                     (error, tempPath))
                 continue
+                
+            # create_pages
+            error = os.system(
+                "%s manage.py create_pages" % sys.executable)
+            if not error == 0:
+                logger.error(
+                    "create_pages error code: %d, from template: %s" % 
+                    (error, tempPath))
+                continue
+                
+            # pluginize
+            error = os.system(
+                "%s manage.py pluginize" % sys.executable)
+            if not error == 0:
+                logger.error(
+                    "pluginize error code: %d, from template: %s" % 
+                    (error, tempPath))
+                continue
+                
+            # fix_template
+            error = os.system(
+                "%s manage.py fix_template" % sys.executable)
+            if not error == 0:
+                logger.error(
+                    "fix_template error code: %d, from template: %s" % 
+                    (error, tempPath))
+                continue
 
             # dumpdata
             error = os.system(
