@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 9906 2017-04-23 15:13:49Z Lavender $
+# $Id: pluginize.py 9978 2017-05-20 15:24:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-23 23:13:49 +0800 (週日, 23 四月 2017) $
-# $Revision: 9906 $
+# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
+# $Revision: 9978 $
 
 import os
 import json
@@ -35,6 +35,9 @@ from filer.models.filemodels import File
 from cms.models.pagemodel import Page
 from lxml.html import fromstring
 
+from Zephyrus.boilerplate.management.commands import (
+    TEMPLATES_DIR_PATH, STATIC_DIR_PATH, FIXTURES_DIR_PATH, ROOT_DIR_PATH)
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 handler = logging.StreamHandler()
@@ -42,34 +45,7 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-os.chdir('.')
-
-ROOT_DIR_PATH = os.path.abspath(
-    os.path.join('.'))
-    
-if hasattr(settings, 'TEMPLATES'):
-    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
-else:
-    TEMPLATES_DIR_PATH = os.path.abspath(
-        os.path.join('.', 'templates'))
-    
-if settings.DEBUG:
-    if hasattr(settings, 'STATICFILES_DIRS'):
-        STATIC_DIT_PATH = settings.STATICFILES_DIRS[0]
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-else:
-    if hasattr(settings, 'STATIC_ROOT'):
-        STATIC_DIT_PATH = settings.STATIC_ROOT
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-            
-FIXTURES_DIT_PATH = os.path.abspath(
-    os.path.join('.', 'fixtures'))
-
-jsPath = os.path.join(STATIC_DIT_PATH, 'js', 'FixTemplate.js')
+jsPath = os.path.join(STATIC_DIR_PATH, 'js', 'FixTemplate.js')
 
 complexity = 0
 
@@ -162,49 +138,6 @@ class Placeholder2(Placeholder):
                         Img(placeholder.slot, 
                         hashlib.md5(placeholder.slot).hexdigest(), attrList))
                     
-                    """
-                    code = 'img' + hashlib.md5(url).hexdigest()
-                    slot = placeholder.slot
-                    # filer_image 
-                    with open(jsPath, 'a+') as f:
-                        for k, v in attrs:
-                            divIf = "if($j('#%s').val() == ''){\n" % (slot)
-                            nextImg = "$j('#%s').next()" % (slot)
-                            next3Img = "$j('#%s').next().next().next()" % (slot)
-                            jsIf = ( 
-                                "if(%s.attr('class').search('filer_image')"
-                                " >= 0){\n") % nextImg
-                            jsElseIf = (
-                                "} else if (%s.attr('class').search("
-                                "'filer_image') >= 0){\n") % next3Img
-                            if k == 'class':
-                                js = divIf + jsIf
-                                js += (
-                                    "var %s = %s.attr('class');\n"
-                                    ) % (code, nextImg)
-                                js += (
-                                    "%s.attr('class', '%s ' + %s);\n"
-                                    ) % (nextImg, v, code)
-                                js += jsElseIf
-                                js += (
-                                    "var %s = %s.attr('class');\n"
-                                    ) % (code, next3Img)
-                                js += (
-                                    "%s.attr('class', '%s ' + %s);\n"
-                                    ) % (next3Img, v, code)
-                                js += "}\n}\n"
-                            elif k == 'id' or k == 'style':
-                                js = divIf + jsIf
-                                js = (
-                                    "%s.attr('%s', '%s');\n") % (next3Img, k, v)
-                                js += jsElseIf
-                                js = (
-                                    "%s.attr('%s', '%s');\n") % (next3Img, k, v)
-                                js += "}\n}\n"
-                            else:
-                                continue
-                            f.write(js + '\n')
-                    """
                     
                     FilerImage.objects.create(placeholder=placeholder,
                                               language=Placeholder2.lang,
@@ -238,6 +171,9 @@ class Command(BaseCommand):
         
         if language:
             Placeholder2.lang = language
+        else:
+            if hasattr(settings, 'LANGUAGE_CODE'):
+                Placeholder2.lang = settings.LANGUAGE_CODE
         
         register.tags['placeholder'] = Placeholder2
         #register.tag(Placeholder2)
@@ -245,13 +181,13 @@ class Command(BaseCommand):
         path = TEMPLATES_DIR_PATH
         logger.error('Processing...')
 
-        if not os.path.exists(os.path.join(STATIC_DIT_PATH, 'js')):
-            os.mkdir(os.path.join(STATIC_DIT_PATH, 'js'))
+        if not os.path.exists(os.path.join(STATIC_DIR_PATH, 'js')):
+            os.mkdir(os.path.join(STATIC_DIR_PATH, 'js'))
             
-        if not os.path.exists(FIXTURES_DIT_PATH):
-            os.mkdir(FIXTURES_DIT_PATH)
+        if not os.path.exists(FIXTURES_DIR_PATH):
+            os.mkdir(FIXTURES_DIR_PATH)
             with open(
-                os.path.join(FIXTURES_DIT_PATH, '__init__.py'), 'w') as f:
+                os.path.join(FIXTURES_DIR_PATH, '__init__.py'), 'w') as f:
                 pass
             
         if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
@@ -294,7 +230,7 @@ class Command(BaseCommand):
         for img in imgList:
             if not img in newImgList:
                 newImgList.append(img)
-        temp = get_template('js/FixTemplate.js')
+        temp = get_template('boilerplate/js/FixTemplate.js')
         replaceStr = Context({
             'imgList': newImgList, 
         })
