@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 9976 2017-05-16 06:31:28Z Lavender $
+# $Id: setup.py 9979 2017-05-20 16:33:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
-# $Revision: 9976 $ 
+# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
+# $Revision: 9979 $ 
 
 import os
 import sys
@@ -55,15 +55,16 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                 index = len(os.path.join(SETUP_DIR, "static")) + 1
                 dst = os.path.join(staticDir, origin[index:])
             elif "templates" in root:
+                result = os.path.splitext(origin)[0]
                 if mode == 'programmer':
-                    if 'Fix' in f:
+                    if result.endswith("_user"):
                         continue
                     dst = os.path.join(templateDir, f)
                 else:
-                    if 'Fix' not in f:
+                    if not result.endswith("_user"):
                         continue
                     dst = os.path.join(
-                        templateDir, f.replace('Fix.html', '.html'))
+                        templateDir, f.replace('_user.html', '.html'))
             elif "fixtures" in root:
                 index = len(os.path.join(SETUP_DIR, "fixtures")) + 1
                 dst = os.path.join(baseDir, "fixtures", origin[index:])
